==> mutual_credit-5.0.1.tar.gz: mutual_credit/src/Form/TransactionStatsFilterForm.php <==
<?php

namespace Drupal\mcapi\Form;

Use Drupal\Core\Entity\EntityTypeManager;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\mcapi\Mcapi;
use Drupal\mcapi\Entity\Type;

/**
 * Provides a form for forms.
 */
class TransactionStatsFilterForm extends FormBase {

  protected $entityTypeManager;

  /**
   * Constructor
   *
   * @param EntityTypeManager $entity_type_manager
   */
  public function __construct(EntityTypeManager $entity_type_manager) {
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'transaction_stats_filter';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $args = func_get_args();
    $currency = $form_state->get('currency');
    $previous = isset($_SESSION['transaction_stats_filter']) ?  $_SESSION['transaction_stats_filter'] : [];

    $form['since'] = [
      '#title' => $this->t('Since'),
      '#type' => 'select',
      '#options' => [
        0 => $this->t('All time'),
      ],
      '#default_value' => isset($previous['since']) ? $previous['since'] : 0
    ];
    $form['until'] = [
      '#title' => $this->t('Until'),
      '#type' => 'select',
      '#empty_option' => t('Now'),
      '#required' => FALSE,
      '#default_value' => isset($previous['until']) ? $previous['until'] : REQUEST_TIME
    ];

    $earliest = $currency->firstUsed();
    $month = intval(date('M', $earliest));
    $year = intval(date('Y', $earliest));

    // @todo This could be tidier
    if ($earliest > strtotime('-3 months')) {
      unset($form['until'], $form['since']);
    }
    if ($earliest > strtotime('-2 years')) {
      // System is less than two years old, so show months
      $start_of_month = strtotime("01-{$month}-{$year}");
      while ($start_of_month < REQUEST_TIME) {
        $this->nextMonth($month, $year);
        $start_of_month = strtotime('01-'.$month.'-'.$year);
        $end_of_month = strtotime('01-'.($month+1).'-'.$year) -1;
        $form['since']['#options'][$start_of_month.':'.$end_of_month] = date('M', $start_of_month) .', '.date('Y', $start_of_month);
        $form['until']['#options'][$end_of_month] = date('Y', $end_of_month);}
    }
    elseif ($earliest < strtotime('-2 years')) {
      // System is more than 2 years old, so show years.
      $start_of_year = strtotime('01-01-'.$year);
      //$form['since']['#options'][$next_year] = date('Y', $next_year);
      while ($start_of_year < REQUEST_TIME) {
        $form['since']['#options'][$start_of_year] = date('Y', $start_of_year);
        $year++;
        $form['until']['#options'][strtotime('01-01-'.$year)-1] = $year;
        $start_of_year = strtotime('01-01-'.$year);
      }
    }
    // Ideally 'until' would be set by ajax to prevent dates before 'since'

    $form['type'] = [
      '#title' => $this->t('Transaction type'),
      '#type' => 'select',
      '#required' => FALSE,
      '#default_value' => isset($previous['type']) ? $previous['type'] : '',
      '#options' => Mcapi::entityOptionsList(Type::loadMultiple()),
      '#empty_option' => $this->t('- Any -')
    ];
    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Filter'),
      '#weight' => 20
    ];
    $form['reset'] = [
      '#type' => 'submit',
      '#value' => $this->t('Reset'),
      '#limit_validation_errors' => [],
      '#submit' => ['::resetForm'],
      '#weight' => 21
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $form_state->cleanValues();
    foreach ($form_state->getValues() as $key => $val) {
      $_SESSION['transaction_stats_filter'][$key] = $val;
    }
  }

  public function resetForm(array &$form, FormStateInterface $form_state) {
    unset($_SESSION['transaction_stats_filter']);
  }

  /**
   *
   * @param int $month
   * @param int $year
   * @return void
   */
  private function nextMonth(int &$month, int &$year) : void {
    if ($month == 12) {
      $month = 1;
      $year++;
    }
    else $month++;
  }
}

==> mutual_credit-5.0.9.tar.gz: mutual_credit/src/Form/TransactionStatsFilterForm.php <==
<?php

namespace Drupal\mcapi\Form;

Use Drupal\Core\Entity\EntityTypeManager;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\mcapi\Mcapi;
use Drupal\mcapi\Entity\Type;

/**
 * Provides a form for forms.
 */
class TransactionStatsFilterForm extends FormBase {

  protected $entityTypeManager;

  /**
   * Constructor
   *
   * @param EntityTypeManager $entity_type_manager
   */
  public function __construct(EntityTypeManager $entity_type_manager) {
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'transaction_stats_filter';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $args = func_get_args();
    $currency = $form_state->get('currency');
    $previous = isset($_SESSION['transaction_stats_filter']) ?  $_SESSION['transaction_stats_filter'] : [];

    $form['since'] = [
      '#title' => $this->t('Since'),
      '#type' => 'select',
      '#options' => [
        0 => $this->t('All time'),
      ],
      '#default_value' => isset($previous['since']) ? $previous['since'] : 0
    ];
    $form['until'] = [
      '#title' => $this->t('Until'),
      '#type' => 'select',
      '#empty_option' => t('Now'),
      '#required' => FALSE,
      '#default_value' => isset($previous['until']) ? $previous['until'] : REQUEST_TIME
    ];

    $earliest = $currency->firstUsed();
    $month = intval(date('M', $earliest));
    $year = intval(date('Y', $earliest));

    // @todo This could be tidier
    if ($earliest > strtotime('-3 months')) {
      unset($form['until'], $form['since']);
    }
    if ($earliest > strtotime('-2 years')) {
      // System is less than two years old, so show months
      $start_of_month = strtotime("01-{$month}-{$year}");
      while ($start_of_month < REQUEST_TIME) {
        $this->nextMonth($month, $year);
        $start_of_month = strtotime('01-'.$month.'-'.$year);
        $end_of_month = strtotime('01-'.($month+1).'-'.$year) -1;
        $form['since']['#options'][$start_of_month.':'.$end_of_month] = date('M', $start_of_month) .', '.date('Y', $start_of_month);
        $form['until']['#options'][$end_of_month] = date('Y', $end_of_month);}
    }
    elseif ($earliest < strtotime('-2 years')) {
      // System is more than 2 years old, so show years.
      $start_of_year = strtotime('01-01-'.$year);
      //$form['since']['#options'][$next_year] = date('Y', $next_year);
      while ($start_of_year < REQUEST_TIME) {
        $form['since']['#options'][$start_of_year] = date('Y', $start_of_year);
        $year++;
        $form['until']['#options'][strtotime('01-01-'.$year)-1] = $year;
        $start_of_year = strtotime('01-01-'.$year);
      }
    }
    // Ideally 'until' would be set by ajax to prevent dates before 'since'

    $form['type'] = [
      '#title' => $this->t('Filter by transaction type'),
      '#type' => 'select',
      '#required' => FALSE,
      '#default_value' => isset($previous['type']) ? $previous['type'] : '',
      '#options' => Mcapi::entityOptionsList(Type::loadMultiple()),
      '#empty_option' => $this->t('- Any -')
    ];
    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Filter'),
      '#weight' => 20
    ];
    $form['reset'] = [
      '#type' => 'submit',
      '#value' => $this->t('Reset'),
      '#limit_validation_errors' => [],
      '#submit' => ['::resetForm'],
      '#weight' => 21
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $form_state->cleanValues();
    foreach ($form_state->getValues() as $key => $val) {
      $_SESSION['transaction_stats_filter'][$key] = $val;
    }
  }

  public function resetForm(array &$form, FormStateInterface $form_state) {
    unset($_SESSION['transaction_stats_filter']);
  }

  /**
   *
   * @param int $month
   * @param int $year
   * @return void
   */
  private function nextMonth(int &$month, int &$year) : void {
    if ($month == 12) {
      $month = 1;
      $year++;
    }
    else $month++;
  }
}
